@@ -1,11 +1,9 @@
-pub mod motion;
-pub mod button;
 pub mod input_plugin;
 pub mod buffer;
 pub mod mapping;
+pub mod input_events;
 
-pub use motion::*;
-pub use button::*;
+pub use input_events::*;
 pub use buffer::*;
 pub use input_plugin::*;
 pub use mapping::*;
